#!/usr/bin/env node

/**
 * Tmplify prototype.
 */

"use strict";

process.chdir(__dirname + '/..');

const path = require('path'),
    fs = require('fs'),
    apeTasking = require('ape-tasking'),
    tmplconv = require('tmplconv');

const scaffold = require('../lib');

let demo = path.dirname(require.resolve('apeman-demo-react/package.json'));

apeTasking.runTasks('tmplify', [
   (callback) => {
        tmplconv.tmplify(demo, 'asset/tmpl', {
            clean: true,
            mode: '444',
            pattern: [
                '+(bin|lib|test)/.*.bud',
                '+(bin|lib|test)/.*.hbs',
                'test/._test.js.bud',
                'doc/demo/.*.*',
                '**/*.*',
                '.*'
            ],
            ignore: [
                '.DS_Store',
                '.svn',
                'node_modules/**/*.*',
                'node_modules/**/.*',
                'ci/demo.js',
                'lib/index.js',
                'lib/*.js',
                'README.md',
                'LICENSE'
            ],
            data: {
                'github_repository': "apeman-demo-labo/apeman-demo-react",
                'package_name': 'apeman-demo-react',
                'package_description': 'Demo of React component.',
                'component_name': "DemoComponent",
                'author_name': 'okunishinishi',
                'author_email': 'okunishitaka.com@gmail.com',
                'author_url': 'http://okunishitaka.com'
            },
            prefix: scaffold.prefix,
            suffix: scaffold.suffix
        }, callback);
    },
   (callback) => {
        tmplconv.tmplify(__dirname + '/..', 'asset/tmpl', {
            pattern: [
                '.gitignore'
            ],
            prefix: scaffold.prefix,
            suffix: scaffold.suffix
        }, callback);
    },
   (callback) => {
        let filename = require.resolve('../asset/tmpl/package.json.tmpl');
        let str = fs.readFileSync(filename).toString();
        let pkg = JSON.parse(str);
        fs.chmodSync(filename, '644');
        fs.writeFileSync(filename, JSON.stringify({
            name: pkg.name,
            version: '1.0.0',
            description: pkg.description,
            main: pkg.main,
            scripts: pkg.scripts,
            repository: pkg.repository.url.split(/\//g).slice(-1).join('/').replace(/\.git$/, ''),
            keywords: pkg.keywords,
            author: pkg.author,
            license: pkg.license,
            bugs: pkg.bugs,
            homepage: pkg.homepage,
            dependencies: pkg.dependencies,
            devDependencies: pkg.devDependencies
        }, null, 2));
        fs.chmodSync(filename, '444');
        callback(null);
    }
], true);
